@@ -36,6 +36,8 @@
 #include "orb-core-private.h"
 #include "orbit-debug.h"
 
+int ORBit_small_flags = ORBIT_SMALL_FAST_LOCALS;
+
 gpointer
 ORBit_small_alloc (CORBA_TypeCode tc)
 {
@@ -56,7 +58,6 @@ ORBit_small_freekids (CORBA_TypeCode tc, gpointer p, gpointer d)
 	ORBit_freekids_via_TypeCode (tc, p);
 }
 
-
 static void
 ORBit_handle_exception_array (GIOPRecvBuffer     *rb,
 			      CORBA_Environment  *ev,
@@ -327,7 +328,7 @@ orbit_small_marshal (CORBA_Object           obj,
 
 	dprintf (MESSAGES, "Marshal: id 0x%x\n", request_id);
 
-	for (i = 0; (m_data->arguments._buffer &&
+	for (i = 0; (i < m_data->arguments._length &&
 		     m_data->arguments._buffer [i].flags); i++) {
 
 		ORBit_IArg *a = &m_data->arguments._buffer [i];
@@ -451,7 +452,7 @@ orbit_small_demarshal (CORBA_Object           obj,
 		int i;
 		int trace_have_out = 0;
 
-		for (i = 0; (m_data->arguments._buffer &&
+		for (i = 0; (i < m_data->arguments._length &&
 			     m_data->arguments._buffer [i].flags); i++) {
 			const ORBit_IArg *a;
 			gpointer          arg;
@@ -559,6 +560,19 @@ orbit_small_demarshal (CORBA_Object           obj,
 	}
 }
 
+void
+ORBit_small_invoke_stub_n (CORBA_Object        object,
+			   ORBit_IMethods     *methods,
+			   glong               index,
+			   gpointer            ret,
+			   gpointer           *args,
+			   CORBA_Context       ctx,
+			   CORBA_Environment  *ev)
+{
+	/* FIXME: validate on the sequence length ? */
+	ORBit_small_invoke_stub (object, &methods->_buffer[index], ret, args, ctx, ev);
+}
+
 void
 ORBit_small_invoke_stub (CORBA_Object       obj,
 			 ORBit_IMethod     *m_data,
@@ -1063,7 +1077,8 @@ async_recv_cb (ORBitAsyncQueueEntry *aqe)
 	/* So we don't get invoked again */
 	aqe->mqe.u.unthreaded.cb = NULL;
 
-	if (aqe->mqe.cnx->parent.status == LINC_DISCONNECTED)
+	if (!aqe->mqe.cnx ||
+	    aqe->mqe.cnx->parent.status == LINC_DISCONNECTED)
 		CORBA_exception_set_system (ev, ex_CORBA_COMM_FAILURE,
 					    aqe->completion_status);
 
